@@ -199,6 +199,18 @@ class RpcExchangerClient:
             self._chat_list.remove(id)
         return True
 
+    async def chat_list_somebody_joined(self) -> list[tuple[int, str]]:
+        self.check_authorized()
+        result: list[tuple[int, str]] = [
+            tuple(i) for i in await self._rpc.chat_list_somebody_joined(id=self._uid)
+        ]
+        async with self._chat_list_lock:
+            for value, name in result:
+                if value not in self._chat_list:
+                    await self._pubsub.subscribe(f"messages:{value}")
+                    self._chat_list.add(value)
+        return result
+
     def __aiter__(self) -> RpcExchangerClient:
         return self
 
@@ -211,9 +223,6 @@ class RpcExchangerClient:
 
     async def __aexit__(self, *args) -> None:
         await self._pubsub_raw.__aexit__(None, None, None)
-        async with self._chat_list_lock:
-            for i in self._chat_list.copy():
-                await self.chat_quit(i)
         return None
 
 
